use Test::More tests => 1;

BEGIN {
use_ok( 'Pod::Simple::Text::Termcap' );
}

diag( "Testing Pod::Simple::Text::Termcap $Pod::Simple::Text::Termcap::VERSION, Perl 5.008004, /usr/local/cb/perl5.8.4/bin/perl" );
